@@ -5,8 +5,8 @@ use prima_datadog::Datadog;
 
 #[test]
 pub fn decr_with_literal() {
-    let mock = mocks::decr_mock("env:test", &[]);
-    Datadog::new(mock, true, vec![]).decr("env:test", vec![]);
+    let mock = mocks::decr_mock("test", &[]);
+    Datadog::new(mock, true, vec![]).decr("test", vec![]);
 }
 
 #[test]
@@ -17,8 +17,8 @@ pub fn decr_with_type() {
 
 #[test]
 pub fn decr_with_literal_and_tags() {
-    let mock = mocks::decr_mock("env:test", &["added:tag", "env:test"]);
-    Datadog::new(mock, true, ["env:test"]).decr("env:test", vec!["added:tag".to_string()]);
+    let mock = mocks::decr_mock("test", &["added:tag", "env:test"]);
+    Datadog::new(mock, true, ["env:test"]).decr("test", vec!["added:tag".to_string()]);
 }
 
 #[test]
